pub trait VecFlatten<T2> {
// Required method
fn flatten(&self) -> &[T2];
}Required Methods
Implementations on Foreign Types
Sourceimpl<T, T2> VecFlatten<T2> for [VecType<T>]where
T: VecTypeTrait<Elem = T2>,
Useful to optimize code with vector load/store.
If length of the slice is not a multiple of N,
the remaining elements will be ignored.
impl<T, T2> VecFlatten<T2> for [VecType<T>]where
T: VecTypeTrait<Elem = T2>,
Useful to optimize code with vector load/store. If length of the slice is not a multiple of N, the remaining elements will be ignored.
Safety
This is safe since VecType
compatible with T::Elem array.